@@ -13,11 +13,6 @@ log=logging.getLogger(__name__)
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 
-
-
-# 假设 log 已在包初始化时配置（如之前优化的 get_logger() 返回的日志器）
-# 若未初始化，可添加：log = get_logger()
-
 def enter_and_leave_function(func: Callable) -> Callable:
     """
     函数调用日志装饰器：
@@ -30,9 +25,10 @@ def enter_and_leave_function(func: Callable) -> Callable:
     def wrapper(*args: Any, **kwargs: Any) -> Any:
         # 获取函数定义的文件路径和行号（基础位置信息）
         func_def_file = inspect.getsourcefile(func) or "unknown_file"
+        func_def_file = func_def_file.split("/")[-1]
         func_def_line = inspect.getsourcelines(func)[1] if func_def_file != "unknown_file" else "unknown_line"
         log.info(
-            f"[{func_def_file}:{func_def_line}]"
+            f"[{func_def_file}: {func_def_line}]"
             f"[{func.__name__}()]"
             f"| args={args}, kwargs={kwargs}"
         )
@@ -40,7 +36,8 @@ def enter_and_leave_function(func: Callable) -> Callable:
         try:
             result = func(*args, **kwargs)
             log.info(
-                f"| finish run function {func.__name__}(), return value is: {result} "
+                f"[{func_def_file}: {func_def_line}]"
+                f" finish run function {func.__name__}(), return value is: {result} "
             )
             return result
 
@@ -48,6 +45,7 @@ def enter_and_leave_function(func: Callable) -> Callable:
             error_traceback = traceback.format_exc()
 
             log.error(
+                f"[{func_def_file}: {func_def_line}]"
                 f"failed to run function {func.__name__}() :Failed. "
                 f"| error_type：{type(e).__name__} "
                 f"| error_message：{str(e)} "
